# Based on https://github.com/pmclanahan/django-celery-email/
# Copyright (c) 2010, Paul McLanahan
# All rights reserved.
import logging

import dramatiq
from django.conf import settings
from django.core.mail import get_connection

from django_dramatiq_email.utils import dict_to_email, email_to_dict

TASK_CONFIG = {
    "actor_name": "django_dramatiq_email_send_emails",
    "queue_name": "django_email",
}
TASK_CONFIG.update(settings.DRAMATIQ_EMAIL_TASK_CONFIG)


@dramatiq.actor(**TASK_CONFIG)
def send_email(message, backend_kwargs=None):
    message = email_to_dict(message)
    backend_kwargs = backend_kwargs or {}
    conn = get_connection(backend=settings.DRAMATIQ_EMAIL_BACKEND, **backend_kwargs)
    try:
        conn.open()
    except Exception:
        logging.exception("Cannot reach backend %s", settings.DRAMATIQ_EMAIL_BACKEND)

    sent = conn.send_messages([dict_to_email(message)])
    logging.debug("Successfully sent email message to %r.", message["to"])

    conn.close()
    return sent



from django.core.mail.backends.base import BaseEmailBackend

from django_dramatiq_email.tasks import send_email
from django_dramatiq_email.utils import email_to_dict


class DramatiqEmailBackend(BaseEmailBackend):
    def __init__(self, fail_silently=False, **kwargs):
        super().__init__(fail_silently)
        self.init_kwargs = kwargs

    def send_messages(self, email_messages):
        result_tasks = []
        for message in email_messages:
            result_tasks.append(
                send_email.send(email_to_dict(message), self.init_kwargs)
            )
        return result_tasks



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['django_dramatiq_email']

package_data = \
{'': ['*']}

install_requires = \
['django<3.0',
 'django_dramatiq>0.9,<1.0',
 'dramatiq>=1.8.1,<2.0.0',
 'pika>=1.1.0,<2.0.0']

setup_kwargs = {
    'name': 'django-dramatiq-email',
    'version': '1.0.3',
    'description': 'A Django email backend using Dramatiq to send emails using background workers',
    'long_description': '# Django Dramatiq Email\n\nEmail backend for Django sending emails via Dramatiq.\n\n[![Test Status](https://github.com/SendCloud/django-dramatiq-email/workflows/Test/badge.svg?branch=master)](https://github.com/SendCloud/django-dramatiq-email/actions?query=workflow%3ATest)\n[![Lint Status](https://github.com/SendCloud/django-dramatiq-email/workflows/Lint/badge.svg?branch=master)](https://github.com/SendCloud/django-dramatiq-email/actions?query=workflow%3ALint)\n[![Code coverage Status](https://codecov.io/gh/SendCloud/django-dramatiq-email/branch/master/graph/badge.svg)](https://codecov.io/gh/SendCloud/django-dramatiq-email)\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\n## Installation\n\nTo enable `django-dramatiq-email` configure the Django `EMAIL_BACKEND` to `django_dramatiq_email.backends.DramatiqEmailBackend`\nand make sure add Django Dramatiq Email to your Django `INSTALLED_APPS`. This package is tested up to Django 3.\n\n## Configuration\n\nThe dramatiq task\'s configuration can be changed via the setting `DRAMATIQ_EMAIL_TASK_CONFIG` of type dict.\nBy default tasks are being pushed to the \'django_email\' queue. The settings in `DRAMATIQ_EMAIL_TASK_CONFIG`\nare being used at load time to construct the actor.\n\nExample configuration (using the Retry middleware):\n```\nDRAMATIQ_EMAIL_TASK_CONFIG = {\n    "max_retries": 20,\n    "min_backoff": 15000,\n    "max_backoff": 86400000,\n    "queue_name": "my_custom_queue"\n}\n```\n\nYou can change the actual email backend being used by changing `DRAMATIQ_EMAIL_BACKEND`.\n\n## Bulk emails\nBulk emails are send using individual Dramatiq tasks. Doing so these tasks can be restarted individually.\n\n## Maintainer\n[Tim Drijvers](http://github.com/timdrijvers)\n',
    'author': 'Tim Drijvers',
    'author_email': 'tim@sendcloud.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/sendcloud/django-dramatiq-email',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
